@@ -4,8 +4,6 @@ import os
 from contextlib import suppress
 from copy import deepcopy
 from dataclasses import dataclass, field
-from dateutil.tz import gettz
-from datetime import datetime
 from functools import lru_cache
 from glob import glob
 from hashlib import md5
@@ -18,15 +16,14 @@ import aiohttp_jinja2
 import aiopg
 import aioredis
 import jinja2
+import pytz
+
 from aiojobs.aiohttp import setup as aiojobs_setup
 from aiohttp.web_urldispatcher import UrlDispatcher
 from cryptography.fernet import Fernet
 
-DEFAULT_TZ = os.environ.get("DEFAULT_TZ")
-parsed_tz = gettz(DEFAULT_TZ)
-if DEFAULT_TZ:
-    assert parsed_tz, f'Time zone {DEFAULT_TZ} was not recognized'
-local_tz = (parsed_tz or gettz()).tzname(datetime.now())
+DEFAULT_TZ = os.environ.get("DEFAULT_TZ", 'UTC')
+local_tz = pytz.timezone(DEFAULT_TZ)
 
 from .commons import Commons
 from .core import build_app
@@ -67,7 +64,7 @@ async def cleanup(app):
 
 async def on_connect_postgres(conn):
     async with conn.cursor() as cur:
-        await cur.execute("SET session TIME ZONE %s", [local_tz])
+        await cur.execute("SET session TIME ZONE %s", [local_tz.zone])
 
 
 async def init_resources(app):
@@ -184,6 +181,9 @@ class AppConfig:
     verification_email_html: str = ''
 
     plugins: List[str] = field(default_factory=list)
+    before_request_hooks: List[Callable] = field(default_factory=list)
+    after_request_hooks: List[Callable] = field(default_factory=list)
+    metainfo_extender: Callable = None
 
     def _update(self, cls):
         for k, v in cls.__dict__.items():
@@ -263,7 +263,6 @@ class PathReturner:
             viewname = resource._routes[0].handler.__name__.replace('View', '')
             viewname = viewname[0].lower() + viewname[1:]
 
-            # with suppress(KeyError):
             view_spec = spec['paths'].get(url)
             if not view_spec:
                 continue
@@ -289,12 +288,19 @@ class PathReturner:
 async def apispec_metainfo(request):
     '''Return current hashsum for the OpenAPI spec + authentication status'''
     is_authed = request.session.is_authed
+
     base_ctxt = {
         'spec_hashsum': request.app.spec_hash,
         'authed': is_authed
     }
+
     if not is_authed:
         return json_response(base_ctxt)
+
+    with suppress(AttributeError, ValueError, TypeError):
+        ext = await request.app.config.metainfo_extender(request) or {}
+        base_ctxt.update(ext)
+
     return json_response({
         'scopes': request.app.scopes,
         'roles': request.app.allowed_roles,
