@@ -14,7 +14,7 @@ from . import ALLOWED_OPERATIONS
 from .auth.context import AuthContext
 from .exceptions import HTTPShieldedResource
 from .utils import generate_num_sequence
-from .view import AuxViewBase
+from .view_bases import AuxViewBase
 
 APP_MODE = os.environ.get('APP_MODE', 'test')
 
@@ -24,11 +24,10 @@ def set_init_logging_context(request):
         IP = request.transport.get_extra_info('peername')[0]
     except (IndexError, AttributeError):
         IP = '0.0.0.0'
-    request.app.IP = IP
+    request.IP = IP
 
 
 def set_logging_context(app, **context):
-    context['ip_address'] = app.IP
     if 'sentry' in app.installed_plugins:
         with configure_scope() as scope:
             scope.user = context
@@ -59,12 +58,16 @@ async def switch_workspace(request):
                 request.is_overwritten = True
                 request.session._session_ctxt['workspace'] = overwrite_to
 
+        for before_handler in request.app.config.before_request_hooks:
+            await before_handler(request)
         yield request
 
     finally:
         if calling_workspace:
             # session exists AND Overwrite header has been used
             request.session._session_ctxt['workspace'] = calling_workspace
+        for after_handler in request.app.config.after_request_hooks:
+            await after_handler(request)
 
 
 async def prepare_shielded_response(request, handler):
@@ -161,11 +164,11 @@ async def postschema_middleware(request, handler):
         request.operation = request.method.lower()
         auth_ctxt = AuthContext(request)
         auth_ctxt.request_type = 'public'
+        auth_ctxt.ip_address = request.IP
         request.session = auth_ctxt
         try:
             await auth_ctxt.set_session_context()
         except web.HTTPUnauthorized as unauth_exc:
-            actor_id = getattr(unauth_exc, 'actor_id', 'Unrecognized')
             request.session = {}
             request.session['actor_id'] = getattr(unauth_exc, 'actor_id', 'Unrecognized')
         return await handler(request)
@@ -177,6 +180,7 @@ async def postschema_middleware(request, handler):
         request.operation = request.method.lower()
         auth_ctxt = AuthContext(request)
         auth_ctxt.request_type = 'public'
+        auth_ctxt.ip_address = request.IP
         request.session = auth_ctxt
         await auth_ctxt.set_session_context()
         return await handler(request)
@@ -185,6 +189,7 @@ async def postschema_middleware(request, handler):
             request.operation = request.method.lower()
             auth_ctxt = AuthContext(request)
             auth_ctxt.request_type = 'authed'
+            auth_ctxt.ip_address = request.IP
             await auth_ctxt.set_session_context()
             if str(auth_ctxt.status) != '1':
                 raise web.HTTPForbidden(reason='Account inactive')
@@ -218,6 +223,7 @@ async def postschema_middleware(request, handler):
     request.operation = op.lower()
 
     auth_ctxt.set_level_permissions()
+    auth_ctxt.ip_address = request.IP
     try:
         await auth_ctxt.set_session_context()
     except web.HTTPException as err_resp:
